@@ -205,8 +205,9 @@ class AmazonSpApi(Client):
             token = self._lock_get_data('grantless_token_', self._get_token, 3000)
         return token['access_token']
 
-    def __init__(self, credentials, is_grantless=False, region=None):
-        super(AmazonSpApi, self).__init__(credentials, is_grantless=is_grantless, region=region)
+    def __init__(self, credentials, is_grantless=False, region=None, redis_config=None):
+        super(AmazonSpApi, self).__init__(credentials, is_grantless=is_grantless, region=region,
+                                          redis_config=redis_config)
         self.boto3_client = boto3.client(
             'sts',
             aws_access_key_id=self.cred.aws_access_key,
